var index =
[
    [ "Introduction", "index.html#Algebraic_foundationsIntroduction", null ],
    [ "Algebraic Structures", "index.html#Algebraic_foundationsAlgebraic", [
      [ "Tags in Algebraic Structure Traits", "index.html#Algebraic_foundationsTagsinAlgebraicStructure", [
        [ "Algebraic Category", "index.html#Algebraic_foundationsAlgebraicCategory", null ],
        [ "Exact and Numerical Sensitive", "index.html#Algebraic_foundationsExactandNumericalSensitive", null ]
      ] ]
    ] ],
    [ "Real Embeddable", "index.html#Algebraic_foundationsRealE", null ],
    [ "Real Number Types", "index.html#Algebraic_foundationsRealN", null ],
    [ "Interoperability", "index.html#Algebraic_foundationsInteroperability", [
      [ "Examples", "index.html#Algebraic_foundationsExamples", null ]
    ] ],
    [ "Fractions", "index.html#Algebraic_foundationsFractions", [
      [ "Examples", "index.html#Algebraic_foundationsExamples_1", null ]
    ] ],
    [ "Design and Implementation History", "index.html#Algebraic_foundationsDesign", null ]
];